searchData={"items":[{"type":"module","title":"KinoPhoenixLiveview","doc":"Provides a simple interface for launching a Phoenix LiveView within a Kino widget.\n\nThis module handles the configuration and startup of a proxy endpoint that\nserves your LiveView inside an iframe. It abstracts away the complexity of setting\nup a full Phoenix endpoint by offering a few preset option combinations.","ref":"KinoPhoenixLiveview.html"},{"type":"module","title":"Usage - KinoPhoenixLiveview","doc":"Call `KinoPhoenixLiveview.new/1` with one of the following option sets:\n\n  1. **Only Path (Use All Defaults)**\n     ```elixir\n     KinoPhoenixLiveview.new(path: \"/proxy/apps/{slug}\")\n     ```\n\n  2. **Custom LiveView**\n     ```elixir\n     KinoPhoenixLiveview.new(path: \"/proxy/apps/{slug}\", live_view: MyApp.LiveView)\n     ```\n\n  3. **Custom LiveView and Layout**\n     ```elixir\n     KinoPhoenixLiveview.new(path: \"/proxy/apps/{slug}\", live_view: MyApp.LiveView, root_layout: MyApp.Layout)\n     ```\n\n  4. **Custom Router**\n     ```elixir\n     KinoPhoenixLiveview.new(path: \"/proxy/apps/{slug}\", router: MyApp.Router)\n     ```\n\n  5. **Custom Endpoint**\n     ```elixir\n     KinoPhoenixLiveview.new(path: \"/proxy/apps/{slug}\", endpoint: MyApp.Endpoint)\n     ```","ref":"KinoPhoenixLiveview.html#module-usage"},{"type":"function","title":"KinoPhoenixLiveview.new/1","doc":"Launches the Kino Phoenix LiveView integration with various configurations.\n\nThe options you pass determine which integration variant is used.\n\n**Variants:**\n\n  - *Only Path:* Uses defaults for LiveView, layout, router, and endpoint.\n  - *Custom LiveView:* Override the default LiveView module.\n  - *Custom LiveView and Layout:* Override both LiveView and layout.\n  - *Custom Router:* Provide your own router.\n  - *Custom Endpoint:* Provide your own endpoint.\n\n**Note:** Each call must include a `:path` key. Do not mix incompatible options.","ref":"KinoPhoenixLiveview.html#new/1"},{"type":"module","title":"KinoPhoenixLiveview.Application","doc":"The main application module for the Kino Phoenix LiveView integration.\n\nThis module defines the application supervision tree, which includes\na PubSub server, a Registry, and the configured endpoint. It is responsible\nfor starting all necessary processes for the LiveView proxy.","ref":"KinoPhoenixLiveview.Application.html"},{"type":"function","title":"KinoPhoenixLiveview.Application.child_spec/1","doc":"Defines the child specification for the application.\n\nThis specification is used by the supervisor to start the application.","ref":"KinoPhoenixLiveview.Application.html#child_spec/1"},{"type":"function","title":"KinoPhoenixLiveview.Application.start/2","doc":"Starts the application supervision tree.\n\nIt starts a PubSub server, a Registry, and the configured Phoenix endpoint.","ref":"KinoPhoenixLiveview.Application.html#start/2"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.Application.start/2","doc":"- `_type`: The type of start (ignored).\n  - `_args`: The start arguments (ignored).","ref":"KinoPhoenixLiveview.Application.html#start/2-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.Application.start/2","doc":"- `{:ok, pid}` on successful startup.","ref":"KinoPhoenixLiveview.Application.html#start/2-returns"},{"type":"module","title":"KinoPhoenixLiveview.DynamicLive","doc":"A dynamic LiveView module that delegates all callbacks to another LiveView.\n\nThe delegated LiveView is determined at runtime via application configuration\n(`:kino_phoenix_live_view, :live_view`). This allows for swapping or extending\nLiveView behavior without modifying this module.","ref":"KinoPhoenixLiveview.DynamicLive.html"},{"type":"module","title":"KinoPhoenixLiveview.DynamicRootLayout","doc":"A plug that dynamically sets the root layout for Phoenix controllers.\n\nIt retrieves the root layout module from the application environment\n(defaulting to `KinoPhoenixLiveview.Layout`) and assigns it to the connection.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html"},{"type":"function","title":"KinoPhoenixLiveview.DynamicRootLayout.call/2","doc":"Sets the root layout for the connection dynamically.\n\nIt fetches the layout from the application configuration and updates the\nconnection using `Phoenix.Controller.put_root_layout/2`.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#call/2"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.DynamicRootLayout.call/2","doc":"- `conn`: The connection struct.\n  - `_opts`: Unused options.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#call/2-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.DynamicRootLayout.call/2","doc":"- The updated connection.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#call/2-returns"},{"type":"function","title":"KinoPhoenixLiveview.DynamicRootLayout.init/1","doc":"Initializes the plug options.\n\nThis plug does not require any special options.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#init/1"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.DynamicRootLayout.init/1","doc":"- `opts`: The plug options.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#init/1-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.DynamicRootLayout.init/1","doc":"- The unchanged options.","ref":"KinoPhoenixLiveview.DynamicRootLayout.html#init/1-returns"},{"type":"module","title":"KinoPhoenixLiveview.DynamicRouterPlug","doc":"A plug that dynamically dispatches requests to a router defined in the application\nconfiguration.\n\nThis plug retrieves the router from the application environment and invokes its\n`call/2` function to handle the request.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html"},{"type":"function","title":"KinoPhoenixLiveview.DynamicRouterPlug.call/2","doc":"Delegates the connection to the dynamically configured router.\n\nIt fetches the router module from the application environment and invokes its\n`call/2` callback.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#call/2"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.DynamicRouterPlug.call/2","doc":"- `conn`: The connection struct.\n  - `_opts`: Unused options.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#call/2-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.DynamicRouterPlug.call/2","doc":"- The updated connection after the router has processed it.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#call/2-returns"},{"type":"function","title":"KinoPhoenixLiveview.DynamicRouterPlug.init/1","doc":"Initializes the plug with the given options.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#init/1"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.DynamicRouterPlug.init/1","doc":"- `opts`: The plug options.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#init/1-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.DynamicRouterPlug.init/1","doc":"- The unchanged options.","ref":"KinoPhoenixLiveview.DynamicRouterPlug.html#init/1-returns"},{"type":"module","title":"KinoPhoenixLiveview.ErrorView","doc":"A minimal error view module for rendering error messages.\n\nThis view simply converts a given error template to a human-readable\nstatus message using Phoenix's built-in functions.","ref":"KinoPhoenixLiveview.ErrorView.html"},{"type":"function","title":"KinoPhoenixLiveview.ErrorView.render/2","doc":"Renders an error message based on the template.","ref":"KinoPhoenixLiveview.ErrorView.html#render/2"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.ErrorView.render/2","doc":"- `template`: The error template identifier (e.g., \"404.html\").\n  - `_`: Unused assigns.","ref":"KinoPhoenixLiveview.ErrorView.html#render/2-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.ErrorView.render/2","doc":"- A string message corresponding to the HTTP status.","ref":"KinoPhoenixLiveview.ErrorView.html#render/2-returns"},{"type":"module","title":"KinoPhoenixLiveview.Iframe","doc":"Provides a Kino JavaScript widget that embeds a Phoenix LiveView\nendpoint inside an iframe. This module leverages `Kino.JS` to render\nan iframe in the notebook.\n\nThe associated JavaScript asset (`main.js`) creates an ` `\nelement with the provided source URL and appends it to the widget's root.","ref":"KinoPhoenixLiveview.Iframe.html"},{"type":"function","title":"KinoPhoenixLiveview.Iframe.new/1","doc":"Creates a new Kino JavaScript widget with the given iframe source.\n\nThis function initializes the widget by calling `Kino.JS.new/2`\nwith the current module and the specified `src`.","ref":"KinoPhoenixLiveview.Iframe.html#new/1"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.Iframe.new/1","doc":"- `src`: A keyword with the key `:src` containing the URL to load\n    in the iframe.","ref":"KinoPhoenixLiveview.Iframe.html#new/1-parameters"},{"type":"function","title":"Examples - KinoPhoenixLiveview.Iframe.new/1","doc":"iex> KinoPhoenixLiveview.Iframe.new(src: \"http://localhost:4000/\")","ref":"KinoPhoenixLiveview.Iframe.html#new/1-examples"},{"type":"function","title":"KinoPhoenixLiveview.Iframe.start/1","doc":"Starts the iframe widget using the given endpoint.\n\nIt extracts the iframe source URL by calling the endpoint's `:path`\nfunction with `\"/\"` and delegates to `new/1`.","ref":"KinoPhoenixLiveview.Iframe.html#start/1"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.Iframe.start/1","doc":"- `endpoint`: The Phoenix endpoint module used to generate the URL.","ref":"KinoPhoenixLiveview.Iframe.html#start/1-parameters"},{"type":"function","title":"Examples - KinoPhoenixLiveview.Iframe.start/1","doc":"iex> KinoPhoenixLiveview.Iframe.start(endpoint: MyApp.Endpoint)","ref":"KinoPhoenixLiveview.Iframe.html#start/1-examples"},{"type":"module","title":"KinoPhoenixLiveview.Layout","doc":"Defines the HTML layout for the Phoenix LiveView embedded\nin a Kino iframe.\n\nThis layout includes essential meta tags, links to static assets\n(e.g. Phoenix and Phoenix LiveView JavaScript files), Tailwind CSS,\nand inline scripts that initialize the LiveView socket connection.","ref":"KinoPhoenixLiveview.Layout.html"},{"type":"function","title":"KinoPhoenixLiveview.Layout.render/2","doc":"Renders the root HTML layout.\n\nThe layout is rendered for the template `\"root.html\"` and expects an\n`assigns` map that may include a `:page_title` and an `@inner_content`\nslot for dynamic content.","ref":"KinoPhoenixLiveview.Layout.html#render/2"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.Layout.render/2","doc":"- `template`: A string identifying the template (must be `\"root.html\"`).\n  - `assigns`: A map of assigns including the page title and content.","ref":"KinoPhoenixLiveview.Layout.html#render/2-parameters"},{"type":"function","title":"Examples - KinoPhoenixLiveview.Layout.render/2","doc":"<.live_title>My LiveView Page</.live_title>\n    ... rest of page ...","ref":"KinoPhoenixLiveview.Layout.html#render/2-examples"},{"type":"module","title":"KinoPhoenixLiveview.ProxyEndpoint","doc":"A Phoenix endpoint that serves as the proxy for the Kino Phoenix LiveView.\n\nIt configures the socket for LiveView, serves static assets required for Phoenix\nand Phoenix LiveView, and uses a dynamic router plug to dispatch requests.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.broadcast/3","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#broadcast/3"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.broadcast!/3","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#broadcast!/3"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.broadcast_from/4","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#broadcast_from/4"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.broadcast_from!/4","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#broadcast_from!/4"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.call/2","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#call/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.child_spec/1","doc":"Returns the child specification to start the endpoint\nunder a supervision tree.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#child_spec/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.config/2","doc":"Returns the endpoint configuration for `key`\n\nReturns `default` if the key does not exist.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#config/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.config_change/2","doc":"Reloads the configuration given the application environment changes.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#config_change/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.host/0","doc":"Returns the host for the given endpoint.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#host/0"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.init/1","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#init/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.local_broadcast/3","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#local_broadcast/3"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.local_broadcast_from/4","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#local_broadcast_from/4"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.path/1","doc":"Generates the path information when routing to this endpoint.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#path/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.script_name/0","doc":"Generates the script name.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#script_name/0"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.server_info/1","doc":"Returns the address and port that the server is running on","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#server_info/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.start_link/1","doc":"Starts the endpoint supervision tree.\n\nAll other options are merged into the endpoint configuration.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#start_link/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.static_integrity/1","doc":"Generates a base64-encoded cryptographic hash (sha512) to a static file\nin `priv/static`. Meant to be used for Subresource Integrity with CDNs.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#static_integrity/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.static_lookup/1","doc":"Returns a two item tuple with the first item being the `static_path`\nand the second item being the `static_integrity`.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#static_lookup/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.static_path/1","doc":"Generates a route to a static file in `priv/static`.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#static_path/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.static_url/0","doc":"Generates the static URL without any path information.\n\nIt uses the configuration under `:static_url` to generate\nsuch. It falls back to `:url` if `:static_url` is not set.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#static_url/0"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.struct_url/0","doc":"Generates the endpoint base URL but as a `URI` struct.\n\nIt uses the configuration under `:url` to generate such.\nUseful for manipulating the URL data and passing it to\nURL helpers.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#struct_url/0"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.subscribe/2","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#subscribe/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.unsubscribe/1","doc":"","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#unsubscribe/1"},{"type":"function","title":"KinoPhoenixLiveview.ProxyEndpoint.url/0","doc":"Generates the endpoint base URL without any path information.\n\nIt uses the configuration under `:url` to generate such.","ref":"KinoPhoenixLiveview.ProxyEndpoint.html#url/0"},{"type":"module","title":"KinoPhoenixLiveview.ProxyRouter","doc":"Defines the router for the Kino Phoenix LiveView proxy.\n\nThis router sets up a browser pipeline that includes the dynamic root layout\nplug and forwards the root path (`\"/\"`) to the `DynamicLive` LiveView.","ref":"KinoPhoenixLiveview.ProxyRouter.html"},{"type":"function","title":"KinoPhoenixLiveview.ProxyRouter.browser/2","doc":"","ref":"KinoPhoenixLiveview.ProxyRouter.html#browser/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyRouter.call/2","doc":"Callback invoked by Plug on every request.","ref":"KinoPhoenixLiveview.ProxyRouter.html#call/2"},{"type":"function","title":"KinoPhoenixLiveview.ProxyRouter.init/1","doc":"Callback required by Plug that initializes the router\nfor serving web requests.","ref":"KinoPhoenixLiveview.ProxyRouter.html#init/1"},{"type":"module","title":"KinoPhoenixLiveview.RootLive","doc":"The default LiveView for KinoPhoenixLiveview, used both to verify LiveView interactions\nand to guide developers on how to customize the integration.\n\nThis LiveView displays a simple toggle button along with instructions on how to:\n  - Replace the default LiveView with a custom one.\n  - Override the layout by providing a custom module.\n  - Override the router or endpoint.\n\nDevelopers can use these instructions as a starting point to build their own LiveView experience.","ref":"KinoPhoenixLiveview.RootLive.html"},{"type":"function","title":"KinoPhoenixLiveview.RootLive.handle_event/3","doc":"Handles the \"toggle\" event by flipping the boolean state.\n\nWhen the button is clicked, the LiveView toggles the value of `:value`.","ref":"KinoPhoenixLiveview.RootLive.html#handle_event/3"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.RootLive.handle_event/3","doc":"- `\"toggle\"`: The event name.\n  - `_params`: The event parameters (unused).\n  - `socket`: The LiveView socket.","ref":"KinoPhoenixLiveview.RootLive.html#handle_event/3-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.RootLive.handle_event/3","doc":"- `{:noreply, socket}` with the updated `:value` assign.","ref":"KinoPhoenixLiveview.RootLive.html#handle_event/3-returns"},{"type":"function","title":"KinoPhoenixLiveview.RootLive.mount/3","doc":"Mounts the LiveView and initializes the socket with a default boolean state.","ref":"KinoPhoenixLiveview.RootLive.html#mount/3"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.RootLive.mount/3","doc":"- `_params`: Request parameters (unused).\n  - `_session`: Session data (unused).\n  - `socket`: The LiveView socket.","ref":"KinoPhoenixLiveview.RootLive.html#mount/3-parameters"},{"type":"function","title":"Returns - KinoPhoenixLiveview.RootLive.mount/3","doc":"- `{:ok, socket}` with the assign `:value` set to `true`.","ref":"KinoPhoenixLiveview.RootLive.html#mount/3-returns"},{"type":"function","title":"KinoPhoenixLiveview.RootLive.render/1","doc":"Renders the default LiveView template.\n\nThe template includes:\n  - A welcome header.\n  - Instructions on how to replace or customize the default LiveView, layout, router, or endpoint.\n  - A display of the current boolean state.\n  - A button to toggle the state for testing interactivity.","ref":"KinoPhoenixLiveview.RootLive.html#render/1"},{"type":"function","title":"Parameters - KinoPhoenixLiveview.RootLive.render/1","doc":"- `assigns`: A map containing the LiveView assigns, including `:value`.","ref":"KinoPhoenixLiveview.RootLive.html#render/1-parameters"},{"type":"function","title":"Example - KinoPhoenixLiveview.RootLive.render/1","doc":"Welcome to KinoPhoenixLiveview! \n     Current value: true \n     Toggle Value","ref":"KinoPhoenixLiveview.RootLive.html#render/1-example"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}